{ -----------------------------------------------------------------------------
   MouseOffRoad - Mouse Counter for Microsoft Windows.
   Copyright (C) 2000  Alexander Kramarenko <groupstudio@mail.ru>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

History:
   14.05.2000 Released under GNU
   15.05.2000 Added ColSch-variable
------------------------------------------------------------------------------ }

unit uVariables;

interface

uses IniFiles, AKTools, SysUtils, Forms, Registry, Windows,
     Graphics;

const
  GV_TOTALDISTANCE   = 0;
  GV_TOTALTIME       = 1;
  GV_AVGSPEED        = 2;

  AutKeyNm    = 'MouseOffRoad 2.0';

  Colors:Array[0..8] of TColor =
         (clBlack,clBlue,clFuchsia,clGray,clGreen,
          clMaroon,clNavy,clPurple,clTeal);


function GetFormattedResult:String;
procedure SaveConfig;
procedure ReadConfig;
function GetValue(vl:Integer):String;

const
  ST_SLEEP = 1;

var
    DistCoof : Double;
    ResultFormat,
    SaveResult : String;
    ShowWnd : boolean;
    SaveConf,
    SleepTime,
    TranspPerc,
    Distance : Integer;
    MostTopWindow : Boolean;
    FirstRun,
    OEMConv : boolean;
    TotalTime,
    ColorSch,
    LabelX,
    LabelY : Integer;

    AutoRun : boolean;

function GetTmeFmt(sec: Integer):String;
function GetDstFmt(cm: Integer):String;
procedure WriteAutorunSt;
procedure ReadAutorunSt;

implementation
uses uMain;

const AF_SPEED     = 0;
      AF_DISTANCE  = 1;
      AF_TIME      = 2;

procedure WriteAutorunSt;
var Reg:TRegistry;
begin
 try
  Reg := TRegistry.Create;
  with Reg do begin
    try
      RootKey := HKEY_CURRENT_USER;
      OpenKey('\Software\Microsoft\Windows\CurrentVersion\Run',True);
      if AutoRun then WriteString(AutKeyNm, ParamStr(0))
                 else DeleteValue(AutKeyNm);
    finally
      Free;
    end; // try
  end; // with
 except {} end; 
end;

procedure ReadAutorunSt;
var Reg:TRegistry;
begin
 try
  Reg := TRegistry.Create;
  with Reg do begin
    try
      RootKey := HKEY_CURRENT_USER;
      OpenKey('\Software\Microsoft\Windows\CurrentVersion\Run',False);
      AutoRun := ReadString(AutKeyNm) <> '';
    finally
      Free;
    end; // try
  end; // with
 except {} end; 
end;

function GetTmeFmt(sec: Integer):String;
var d, h, m, s : integer;
    td, th, tm, ts : Integer;
begin
  s := sec;
  td := Trunc(s/24/60/60); d := td;
  th := Trunc(s/60/60); h := th - td*24;
  tm := Trunc(s/60); m := tm - th*60;
  ts := s; s := ts - tm * 60;

  if d <> 0 then result := result + Format(' %d ', [d]);
  if h <> 0 then result := result + Format(' %d ', [h]);
  if (m <> 0) and (d = 0) then result := result + Format(' %d ', [m]);
  if (s <> 0) and (d = 0) and (h = 0) then result := result + Format(' %d ', [s]);

  if result = '' then result := ' 0 ';  
end;

function GetDstFmt(cm: Integer):String;
var s, m, k : integer;
    ts, tm, tk : Integer;
begin
  s := cm;
  tk := Trunc(s/1000/100); k := tk;
  tm := Trunc(s/100); m := tm - tk*1000;
  ts := s; s := ts - tm * 100;

  if k <> 0 then result := result + Format(' %d ', [k]);
  if m <> 0 then result := result + Format(' %d ', [m]);
  if (s <> 0) and (k = 0) then result := result + Format(' %d ', [s]);

  if result = '' then result := ' 0 ';
end;

function GetValue(vl:Integer):String;
var TotDst : Integer;
begin
  Result := '';
  TotDst := Trunc(Distance*DistCoof*10);
  case vl of
   GV_TOTALDISTANCE : Result := GetDstFmt(TotDst);
   GV_TOTALTIME : Result := GetTmeFmt(TotalTime);
   GV_AVGSPEED : Result := Format('%f /', [(TotDst/100)/(TotalTime/60/60)]);
  end;
end;

function GetFormattedResult:String;
begin
     Result := ResultFormat;
     Result := StringReplace(Result, '[D]', Trim(GetValue(GV_TOTALDISTANCE)), [rfReplaceAll]);
     Result := StringReplace(Result, '[T]', Trim(GetValue(GV_TOTALTIME)), [rfReplaceAll]);
     Result := StringReplace(Result, '[S]', Trim(GetValue(GV_AVGSPEED)), [rfReplaceAll]);
end;

procedure SaveConfig;
var f :TextFile;
begin
   with TIniFile.Create(GetDirectory(ExtractFilePath(Paramstr(0)))+'MouseOffRoad.ini') do
    try
     try
       WriteInteger('DYNAMIC', 'Distance', Distance);
       WriteInteger('DYNAMIC', 'TotalTime', TotalTime);

       WriteBool('MAIN', 'ShowWnd', ShowWnd);
       WriteInteger('MAIN', 'SleepTime', SleepTime);
       WriteFloat('MAIN', 'DistCoof', DistCoof);
       WriteString('MAIN', 'SaveResult', SaveResult);
       WriteString('MAIN', 'ResultFormat', ResultFormat);
       WriteInteger('MAIN', 'AutoSave', SaveConf);
       WriteInteger('MAIN', 'TranspPerc', TranspPerc);

       WriteInteger('MAIN', 'LabelX', LabelX);
       WriteInteger('MAIN', 'LabelY', LabelY);
       WriteInteger('MAIN', 'ColorSch', ColorSch);

       WriteBool('MAIN', 'FirstRun', FirstRun);

       WriteBool('MAIN', 'MostTopWindow', MostTopWindow);
     finally
      Free;
     end;
    except {} end;

   try
    if SaveResult <> '' then
     begin
      AssignFile(f, SaveResult);
      Rewrite(f);
      if OemConv then
       Writeln(f, StrAnsiToOEM(GetFormattedResult))
      else
       Writeln(f, GetFormattedResult);
      CloseFile(f);
     end;
   except {} end;
end;

procedure ReadConfig;
begin
   with TIniFile.Create(GetDirectory(ExtractFilePath(Paramstr(0)))+'MouseOffRoad.ini') do
    try
     try
      DistCoof := ReadFloat('MAIN', 'DistCoof', 0.0005);
      SleepTime := ReadInteger('MAIN', 'SleepTime', 2);
      ShowWnd := ReadBool('MAIN', 'ShowWnd', true);
      SaveResult := ReadString('MAIN', 'SaveResult', 'default.txt');
      ResultFormat := ReadString('MAIN', 'ResultFormat', '    [D]   [S]  [T].');
      SaveConf := ReadInteger('MAIN', 'AutoSave', 6);
      TranspPerc := ReadInteger('MAIN', 'TranspPerc', 60);

      MostTopWindow := ReadBool('MAIN', 'MostTopWindow', true);
      LabelX := ReadInteger('MAIN', 'LabelX', Screen.Width - (fMain.Width + 20));
      LabelY := ReadInteger('MAIN', 'LabelY', Screen.Height - (fMain.Height + 60));
      ColorSch := ReadInteger('MAIN', 'ColorSch', 0);

      Distance := ReadInteger('DYNAMIC', 'Distance', 1);
      TotalTime := ReadInteger('DYNAMIC', 'TotalTime', 1);

      FirstRun := ReadBool('MAIN', 'FirstRun', true);
      OEMConv := ReadBool('MAIN', 'OEMConvert', true);

      if FirstRun then
       begin
        AutoRun := True;
        WriteAutoRunSt;
       end;

     finally
      if Distance = 0 then Distance := 1;
      if TotalTime = 0 then TotalTime := 1;
      Free;
     end;
    except {} end;
end;

end.
